@@ -90,7 +90,7 @@ date         init     comment
 #include <memory.h>
 #include <ctype.h>
 
-#include <xmlstring.h>
+#include <libxml/xmlstring.h>
 
 #ifndef _H_procdefs
 #include  "procdefs.h"
