@@ -31,10 +31,10 @@ date	     init     comment
 */
 
 #include <stdio.h>
-#include <libxml/xmlstring.h>
 
 #include "procdefs.h"
 #include "status.h"
+#include "ncxtypes.h"
 
 #ifdef __cplusplus
 extern "C" {
