@@ -33,8 +33,14 @@ date	     init     comment
 10-nov-07    abb      Split out from ncxconst.h
 */
 
+#ifdef LIBXML2_ENABLED
 #include <libxml/xmlstring.h>
 #include <libxml/xmlregexp.h>
+#else
+typedef unsigned char xmlChar;
+typedef void* xmlRegexpPtr;
+typedef void* xmlTextReaderPtr;
+#endif
 
 #ifndef _H_dlq
 #include "dlq.h"
@@ -535,6 +541,7 @@ typedef struct ncx_iffeature_t_ {
     dlq_hdr_t              qhdr;
     xmlChar               *prefix;
     xmlChar               *name;
+    xmlChar               *expr;
     struct ncx_feature_t_ *feature;
     ncx_error_t            tkerr;
     boolean                seen;          /* for yangdiff */
