@@ -678,9 +678,9 @@ static status_t
     autoload_module (const xmlChar *modname,
                      const xmlChar *revision,
                      ncx_list_t *devlist,
+                     dlq_hdr_t *savedevQ_ptr,
                      ncx_module_t **retmod)
 {
-    dlq_hdr_t               savedevQ;
     ncx_lmem_t             *listmember;
     status_t                res;
     log_debug_t             loglevel;
@@ -693,7 +693,6 @@ static status_t
     }
 
     res = NO_ERR;
-    dlq_createSQue(&savedevQ);
 
     /* first load any deviations */
     if (devlist != NULL) {
@@ -702,7 +701,7 @@ static status_t
              listmember = (ncx_lmem_t *)dlq_nextEntry(listmember)) {
 
             res = ncxmod_load_deviation(listmember->val.str,
-                                        &savedevQ);
+                                        savedevQ_ptr);
             if (res != NO_ERR) {
                 log_error("\nError: Deviation module %s not loaded (%s)!!",
                           listmember->val.str, 
@@ -716,12 +715,12 @@ static status_t
      */
     if (res == NO_ERR) {
         if (LOGDEBUG) {
-            res = ncxmod_parse_module(modname, revision, &savedevQ, retmod);
+            res = ncxmod_parse_module(modname, revision, savedevQ_ptr, retmod);
         } else {
             /* ignore parse warnings during autoload unless debug mode */
             loglevel = log_get_debug_level();
             log_set_debug_level(LOG_DEBUG_ERROR);
-            res = ncxmod_parse_module(modname, revision, &savedevQ, retmod);
+            res = ncxmod_parse_module(modname, revision, savedevQ_ptr, retmod);
             log_set_debug_level(loglevel);
         }
         if (res != NO_ERR) {
@@ -733,8 +732,6 @@ static status_t
         }
     }
 
-    ncx_clean_save_deviationsQ(&savedevQ);
-
     return res;
 
 }  /* autoload_module */
@@ -777,6 +774,7 @@ status_t
     ncx_module_t            *testmod;
     status_t                 res, retres;
     boolean                  need_yt, need_ncx, need_nacm, need_ync;
+    dlq_hdr_t                savedevQ;
 
 #ifdef DEBUG
     if (!server_cb || !scb) {
@@ -848,51 +846,56 @@ status_t
     }
 
     if (retres == NO_ERR) {
+        dlq_createSQue(&savedevQ);
+
         if (need_yt) {
-            testmod = ncx_find_module(NCXMOD_IETF_YANG_TYPES,
-                                      NULL);
-            if (testmod != NULL) {
+            res = ncxmod_load_module(NCXMOD_IETF_YANG_TYPES, NULL, &savedevQ,
+                                     &testmod);
+            if (res == NO_ERR) {
                 res = copy_module_to_tempdir(mscb,
                                              testmod->name,
                                              testmod->version,
                                              testmod->source);
             } else {
-                SET_ERROR(ERR_INTERNAL_VAL);
+                SET_ERROR(res);
             }
         }
         if (need_ncx) {
-            testmod = ncx_find_module(NCXMOD_NCX, NULL);
-            if (testmod != NULL) {
+            res = ncxmod_load_module(NCXMOD_NCX, NULL, &savedevQ, &testmod);
+            if (res == NO_ERR) {
                 res = copy_module_to_tempdir(mscb,
                                              testmod->name,
                                              testmod->version,
                                              testmod->source);
             } else {
-                SET_ERROR(ERR_INTERNAL_VAL);
+                SET_ERROR(res);
             }
         }
         if (need_nacm) {
-            testmod = ncx_find_module(NCXMOD_IETF_NETCONF_ACM, NULL);
-            if (testmod != NULL) {
+            res = ncxmod_load_module(NCXMOD_IETF_NETCONF_ACM, NULL, &savedevQ,
+                                     &testmod);
+            if (res == NO_ERR) {
                 res = copy_module_to_tempdir(mscb,
                                              testmod->name,
                                              testmod->version,
                                              testmod->source);
             } else {
-                SET_ERROR(ERR_INTERNAL_VAL);
+                SET_ERROR(res);
             }
         }
         if (need_ync) {
-            testmod = ncx_find_module(NCXMOD_YUMA_NETCONF, NULL);
-            if (testmod != NULL) {
+            res = ncxmod_load_module(NCXMOD_YUMA_NETCONF, NULL, &savedevQ, &testmod);
+            if (res == NO_ERR) {
                 res = copy_module_to_tempdir(mscb,
                                              testmod->name,
                                              testmod->version,
                                              testmod->source);
             } else {
-                SET_ERROR(ERR_INTERNAL_VAL);
+                SET_ERROR(res);
             }
         }
+
+        ncx_clean_save_deviationsQ(&savedevQ);
     }
     return retres;
 
@@ -950,7 +953,8 @@ status_t
         }
 
         /* skip found modules with errors */          
-        if (!(searchresult->res == ERR_NCX_WRONG_VERSION ||
+        if (searchresult->res != NO_ERR &&
+	    !(searchresult->res == ERR_NCX_WRONG_VERSION ||
               searchresult->res == ERR_NCX_MOD_NOT_FOUND)) {
             continue;
         }
@@ -1086,7 +1090,8 @@ status_t
         }
 
         /* skip found modules with errors */          
-        if (!(searchresult->res == ERR_NCX_WRONG_VERSION ||
+        if (searchresult->res != NO_ERR &&
+            !(searchresult->res == ERR_NCX_WRONG_VERSION ||
               searchresult->res == ERR_NCX_MOD_NOT_FOUND)) {
             continue;
         }
@@ -1187,6 +1192,7 @@ status_t
     res = autoload_module(NCXMOD_YUMA_NETCONF,
                           NULL,
                           NULL, 
+                          &server_cb->autoload_savedevQ,
                           &ncmod);
     if (res == NO_ERR && ncmod != NULL) {
         /* Set the features in yuma-netconf.yang according
@@ -1230,9 +1236,19 @@ status_t
         mod = ncx_find_module(searchresult->module,
                               searchresult->revision);
         if(mod==NULL) {
+            ncx_list_t *devlist = NULL;
+
+            /* prefer the list of deviations from modules-state */
+            if (ncx_list_cnt(&searchresult->devlist) > 0) {
+                devlist = &searchresult->devlist;
+            } else if (searchresult->cap) {
+                devlist = &searchresult->cap->cap_deviation_list;
+            }
+
             res = autoload_module(searchresult->module,
                                   searchresult->revision,
-                                  searchresult->cap?&searchresult->cap->cap_deviation_list:NULL,
+                                  devlist,
+                                  &server_cb->autoload_savedevQ,
                                   &mod);
 
             searchresult->res = res;
