@@ -52,9 +52,6 @@ date         init     comment
 #include <memory.h>
 #include <ctype.h>
 
-#include <libxml/xmlstring.h>
-#include <libxml/xmlreader.h>
-
 #include "procdefs.h"
 #include "c.h"
 #include "c_util.h"
