@@ -32,9 +32,6 @@ date         init     comment
 #include <memory.h>
 #include <ctype.h>
 
-#include <libxml/xmlstring.h>
-#include <libxml/xmlreader.h>
-
 #ifndef _H_procdefs
 #include  "procdefs.h"
 #endif
