@@ -15,22 +15,22 @@ class litenc:
             self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             self.sock.settimeout(timeout)
             self.sock.connect((server, port))
-        except Exception, e:
-            print '*** Connect failed: ' + str(e)
+        except Exception as e:
+            print('*** Connect failed: ' + str(e))
             traceback.print_exc()
             return -1
 
         #self.sock.settimeout(None)
-	#paramiko.util.log_to_file("filename.log")
+        #paramiko.util.log_to_file("filename.log")
         try:
             self.t = paramiko.Transport(self.sock)
             try:
                 self.t.start_client()
             except paramiko.SSHException:
-                print '*** SSH negotiation failed.'
+                print('*** SSH negotiation failed.')
                 return -1
-        except Exception, e:
-            print '*** Connect failed: ' + str(e)
+        except Exception as e:
+            print('*** Connect failed: ' + str(e))
             traceback.print_exc()
             return -1
 
@@ -43,7 +43,7 @@ class litenc:
             self.t.auth_password(user, password)
 
         if not self.t.is_authenticated():
-            print '*** Authentication failed. :('
+            print('*** Authentication failed. :(')
             self.t.close()
             return -1
 
@@ -62,11 +62,11 @@ class litenc:
                 if n <= 0:
                     return -1
                 data = data[n:]
-        except Exception, e:
-            print '*** Caught exception: ' + str(e.__class__) + ': ' + str(e)
+        except Exception as e:
+            print('*** Caught exception: ' + str(e.__class__) + ': ' + str(e))
             traceback.print_exc()
             return -1
-	return 0
+        return 0
 
     def receive(self):
         while True:
@@ -82,7 +82,7 @@ class litenc:
             except socket.timeout:
                 return (1,[])
             if data:
-                self.receive_total_data = self.receive_total_data + str(data)
+                self.receive_total_data = self.receive_total_data + data.decode('ascii')
             else:
                 return (-1,[])
 
@@ -92,7 +92,7 @@ class litenc:
         ret=self.send('''<rpc xmlns="urn:ietf:params:xml:ns:netconf:base:1.0" message-id="'''+str(message_id)+'''">'''+xml+"</rpc>")
         if(ret!=0):
             return (ret,[])
-	(ret,reply_xml)=self.receive()
+        (ret,reply_xml)=self.receive()
         return (ret,reply_xml)
 
     def close(self):
