@@ -7,7 +7,7 @@ import litenc
 import litenc_lxml
 import lxml
 from lxml import etree
-from StringIO import StringIO
+from io import StringIO
 import argparse
 
 # Hmm .. ?!
@@ -32,10 +32,10 @@ def yang_data_equal(e1, e2):
 		print("diff attrib")
 		return False
 	if len(e1) != len(e2):
-		print e1
-		print len(e1)
-		print e2
-		print len(e2)
+		print(e1)
+		print(len(e1))
+		print(e2)
+		print(len(e2))
 		assert(False)
 		return False
 	return all(yang_data_equal(c1, c2) for c1, c2 in zip(e1, e2))
@@ -80,9 +80,9 @@ def main():
 	conn_raw = litenc.litenc()
 	ret = conn_raw.connect(server=server, port=port, user=user, password=password)
 	if ret != 0:
-		print "[FAILED] Connecting to server=%(server)s:" % {'server':server}
+		print("[FAILED] Connecting to server=%(server)s:" % {'server':server})
 		return(-1)
-	print "[OK] Connecting to server=%(server)s:" % {'server':server}
+	print("[OK] Connecting to server=%(server)s:" % {'server':server})
 	conn=litenc_lxml.litenc_lxml(conn_raw,strip_namespaces=True)
 	ret = conn_raw.send("""
 <hello xmlns="urn:ietf:params:xml:ns:netconf:base:1.0">
@@ -99,7 +99,7 @@ def main():
 		print("[FAILED] Receiving <hello>")
 		return(-1)
 
-	print "[OK] Receiving <hello> =%(reply_xml)s:" % {'reply_xml':reply_xml}
+	print("[OK] Receiving <hello> =%(reply_xml)s:" % {'reply_xml':reply_xml})
 
 	print("Connected ...")
 
@@ -113,8 +113,8 @@ def main():
 
 	print("<get> - /ietf-yang-library:modules-state ...")
 	result = conn.rpc(get_yang_library_rpc, strip_ns=False)
-	print lxml.etree.tostring(result, pretty_print=True, inclusive_ns_prefixes=True)
-        namespaces = {"nc":"urn:ietf:params:xml:ns:netconf:base:1.0"}
+	print(lxml.etree.tostring(result, pretty_print=True, inclusive_ns_prefixes=True))
+	namespaces = {"nc":"urn:ietf:params:xml:ns:netconf:base:1.0"}
 	data = result.xpath('./nc:data', namespaces=namespaces)
 	assert(len(data)==1)
 
@@ -145,7 +145,7 @@ def main():
 
 	print("<edit-config> - load example config to 'candidate' ...")
 	result = conn.rpc(edit_config_rpc)
-	print lxml.etree.tostring(result)
+	print(lxml.etree.tostring(result))
 	ok = result.xpath('./ok')
 	assert(len(ok)==1)
 
@@ -153,7 +153,7 @@ def main():
 
 	print("<commit> - commit example config ...")
 	result = conn.rpc(commit_rpc)
-	print lxml.etree.tostring(result)
+	print(lxml.etree.tostring(result))
 	ok = result.xpath('./ok')
 	assert(len(ok)==1)
 
@@ -172,8 +172,8 @@ def main():
 
 	print("<get> - example data ...")
 	result = conn.rpc(get_example_data_rpc, strip_ns=False)
-	print lxml.etree.tostring(result, pretty_print=True, inclusive_ns_prefixes=True)
-        namespaces = {"nc":"urn:ietf:params:xml:ns:netconf:base:1.0"}
+	print(lxml.etree.tostring(result, pretty_print=True, inclusive_ns_prefixes=True))
+	namespaces = {"nc":"urn:ietf:params:xml:ns:netconf:base:1.0"}
 	data = result.xpath('./nc:data', namespaces=namespaces)
 	assert(len(data)==1)
 
@@ -222,14 +222,14 @@ def main():
 	data_received.write_c14n(b)
 
 	if yang_data_equal(lxml.etree.fromstring(a.getvalue()), lxml.etree.fromstring(b.getvalue())):
-		print "Bingo!"
+		print("Bingo!")
 		return 0
 	else:
-		print "Expected (A) different from received (B):"
-		print "A:"
-		print a.getvalue()
-		print "B:"
-		print b.getvalue()
+		print("Expected (A) different from received (B):")
+		print("A:")
+		print(a.getvalue())
+		print("B:")
+		print(b.getvalue())
 		return 1
 
 sys.exit(main())
