@@ -48,9 +48,9 @@ def main():
 	conn_raw = litenc.litenc()
 	ret = conn_raw.connect(server=server, port=port, user=user, password=password)
 	if ret != 0:
-		print "[FAILED] Connecting to server=%(server)s:" % {'server':server}
+		print("[FAILED] Connecting to server=%(server)s:" % {'server':server})
 		return(-1)
-	print "[OK] Connecting to server=%(server)s:" % {'server':server}
+	print("[OK] Connecting to server=%(server)s:" % {'server':server})
 	conn=litenc_lxml.litenc_lxml(conn_raw,strip_namespaces=True)
 	ret = conn_raw.send("""
 <hello xmlns="urn:ietf:params:xml:ns:netconf:base:1.0">
@@ -67,7 +67,7 @@ def main():
 		print("[FAILED] Receiving <hello>")
 		return(-1)
 
-	print "[OK] Receiving <hello> =%(reply_xml)s:" % {'reply_xml':reply_xml}
+	print("[OK] Receiving <hello> =%(reply_xml)s:" % {'reply_xml':reply_xml})
 
 
 	print("Connected ...")
@@ -122,7 +122,7 @@ def main():
 
 	print("edit-config ...")
 	result = conn.rpc(edit_config_rpc)
-	print result
+	print(result)
 	ok = result.xpath('//ok')
 	assert(len(ok)==1)
 
@@ -163,7 +163,7 @@ def main():
 """
 	print("commit ...")
 	result = conn.rpc(commit_rpc)
-	print result
+	print(result)
 	ok = result.xpath('//ok')
 	assert(len(ok)==0)
 
