@@ -49,9 +49,9 @@ def main():
 	conn_raw = litenc.litenc()
 	ret = conn_raw.connect(server=server, port=port, user=user, password=password)
 	if ret != 0:
-		print "[FAILED] Connecting to server=%(server)s:" % {'server':server}
+		print("[FAILED] Connecting to server=%(server)s:" % {'server':server})
 		return(-1)
-	print "[OK] Connecting to server=%(server)s:" % {'server':server}
+	print("[OK] Connecting to server=%(server)s:" % {'server':server})
 	conn=litenc_lxml.litenc_lxml(conn_raw, strip_namespaces=True)
 	ret = conn_raw.send("""
 <hello xmlns="urn:ietf:params:xml:ns:netconf:base:1.0">
@@ -68,7 +68,7 @@ def main():
 		print("[FAILED] Receiving <hello>")
 		return(-1)
 
-	print "[OK] Receiving <hello> =%(reply_xml)s:" % {'reply_xml':reply_xml}
+	print("[OK] Receiving <hello> =%(reply_xml)s:" % {'reply_xml':reply_xml})
 
 
 	print("Connected ...")
@@ -119,22 +119,22 @@ def main():
 """
 	print("edit-config - create  'foo' ...")
 	result = conn.rpc(edit_config_rpc)
-	print lxml.etree.tostring(result)
+	print(lxml.etree.tostring(result))
 	ok = result.xpath('ok')
-	print result
-	print ok
-	print lxml.etree.tostring(result)
+	print(result)
+	print(ok)
+	print(lxml.etree.tostring(result))
 	assert(len(ok)==1)
 
 	commit_rpc = """
 <commit/>
 """
 	result = conn.rpc(commit_rpc)
-	print lxml.etree.tostring(result)
+	print(lxml.etree.tostring(result))
 	ok = result.xpath('ok')
-	print result
-	print ok
-	print lxml.etree.tostring(result)
+	print(result)
+	print(ok)
+	print(lxml.etree.tostring(result))
 	assert(len(ok)==1)
 
 	edit_config_rpc = """
@@ -156,22 +156,22 @@ def main():
 """
 	print("edit-config - create  'foo' ethernet-mac ...")
 	result = conn.rpc(edit_config_rpc)
-	print lxml.etree.tostring(result)
+	print(lxml.etree.tostring(result))
 	ok = result.xpath('ok')
-	print result
-	print ok
-	print lxml.etree.tostring(result)
+	print(result)
+	print(ok)
+	print(lxml.etree.tostring(result))
 	assert(len(ok)==1)
 
 	commit_rpc = """
 <commit/>
 """
 	result = conn.rpc(commit_rpc)
-	print lxml.etree.tostring(result)
+	print(lxml.etree.tostring(result))
 	ok = result.xpath('ok')
-	print result
-	print ok
-	print lxml.etree.tostring(result)
+	print(result)
+	print(ok)
+	print(lxml.etree.tostring(result))
 	assert(len(ok)==1)
 
 	edit_config_rpc = """
@@ -193,21 +193,21 @@ def main():
 """
 	print("edit-config - create  'bar' ethernet-mac ...")
 	result = conn.rpc(edit_config_rpc)
-	print lxml.etree.tostring(result)
+	print(lxml.etree.tostring(result))
 	ok = result.xpath('ok')
-	print result
-	print ok
-	print lxml.etree.tostring(result)
+	print(result)
+	print(ok)
+	print(lxml.etree.tostring(result))
 	#assert(len(ok)==0)
 	commit_rpc = """
 <commit/>
 """
 	result = conn.rpc(commit_rpc)
-	print lxml.etree.tostring(result)
+	print(lxml.etree.tostring(result))
 	ok = result.xpath('ok')
-	print result
-	print ok
-	print lxml.etree.tostring(result)
+	print(result)
+	print(ok)
+	print(lxml.etree.tostring(result))
 	assert(len(ok)==1)
 
 	get_config_rpc = """
