@@ -47,9 +47,9 @@ def main():
 	conn_raw = litenc.litenc()
 	ret = conn_raw.connect(server=server, port=port, user=user, password=password)
 	if ret != 0:
-		print "[FAILED] Connecting to server=%(server)s:" % {'server':server}
+		print("[FAILED] Connecting to server=%(server)s:" % {'server':server})
 		return(-1)
-	print "[OK] Connecting to server=%(server)s:" % {'server':server}
+	print("[OK] Connecting to server=%(server)s:" % {'server':server})
 	conn=litenc_lxml.litenc_lxml(conn_raw, strip_namespaces=True)
 	ret = conn_raw.send("""
 <hello xmlns="urn:ietf:params:xml:ns:netconf:base:1.0">
@@ -65,7 +65,7 @@ def main():
 	# receive <hello>
 	result=conn.receive()
 
-        print("#1 - Verify /modules-state/module[name='test-yang-library-submodules'] container is present.")
+		print("#1 - Verify /modules-state/module[name='test-yang-library-submodules'] container is present.")
 
 	get_rpc = """
 <get xmlns="urn:ietf:params:xml:ns:netconf:base:1.0">
@@ -79,7 +79,7 @@ def main():
 	print("get ...")
 	result = conn.rpc(get_rpc)
 
-	print lxml.etree.tostring(result)
+	print(lxml.etree.tostring(result))
 	name = result.xpath('data/modules-state/module/name')
 	assert(len(name)==1)
 
@@ -94,6 +94,6 @@ def main():
 	assert(len(submodule_name)==1)
 	assert(submodule_name[0].text=="test-yang-library-submodules-sub1")
 
-        return(0)
+		return(0)
 
 sys.exit(main())
